# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ScalingConfigurationArgs', 'ScalingConfiguration']

@pulumi.input_type
class ScalingConfigurationArgs:
    def __init__(__self__, *,
                 eip: Optional[pulumi.Input['ScalingConfigurationEipArgs']] = None,
                 host_name: Optional[pulumi.Input[builtins.str]] = None,
                 hpc_cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type_overrides: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingConfigurationInstanceTypeOverrideArgs']]]] = None,
                 ipv6_address_count: Optional[pulumi.Input[builtins.int]] = None,
                 key_pair_name: Optional[pulumi.Input[builtins.str]] = None,
                 lifecycle_state: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 scaling_configuration_name: Optional[pulumi.Input[builtins.str]] = None,
                 scaling_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 security_enhancement_strategy: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 spot_strategy: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingConfigurationTagArgs']]]] = None,
                 user_data: Optional[pulumi.Input[builtins.str]] = None,
                 volumes: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingConfigurationVolumeArgs']]]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a ScalingConfiguration resource.
        :param pulumi.Input['ScalingConfigurationEipArgs'] eip: 公网IP。
        :param pulumi.Input[builtins.str] host_name: 实例的主机名。取值：Linux实例允许使用点号分隔字符成多段，每段中允许使用字母、数字或中划线“-”。不能以点号“.”或中划线“-”开头或结尾，且不能连续使用点号“.”或中划线“-”。Linux系统的主机名长度限制为2～63个字符。Windows实例允许使用字母、数字或中划线“-”，不能完全是数字。不能以中划线“-”开头或结尾，且不能连续使用中划线“-”。Windows系统的主机名长度限制在2～15个字符。如不填，则遵循以下规则自动生成：结构：iv  - + 初始主机名，例如iv-3tigy72q3u3vj0******。已创建实例保持原主机名生成逻辑，不随实例重启发生变化。初始主机名生成逻辑：Linux：提取实例IDi-之后的全部字符。Windows：提取实例IDi-之后的后12位字符。
        :param pulumi.Input[builtins.str] hpc_cluster_id: 实例所属的高性能计算集群的ID。仅当InstanceTypes.N指定为“高性能计算GPU型”时有效。
        :param pulumi.Input[builtins.str] image_id: 镜像ID，伸缩组自动创建实例时使用的镜像资源。
        :param pulumi.Input[builtins.str] instance_description: 实例的描述，取值：不能以数字、中划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制在0 ~ 255之间。不填默认为空字符串。
        :param pulumi.Input[builtins.str] instance_name: 实例的名称，取值：以字母或中文开头。只能包含中文、字母、数字、下划线“_”、中划线“-”和点号“.”。长度限制为1～128个字符。
        :param pulumi.Input[builtins.int] ipv6_address_count: 是否为实例网卡分配IPv6地址。取值：0：不分配IPv6地址。1：分配IPv6地址，系统自动为您分配IPv6网段。
        :param pulumi.Input[builtins.str] key_pair_name: KeyPairName string 可选 示例值：kp-test-123，使用“SSH密钥对”登录实例时，请输入密钥对的名称。如果同时设置了KeyPairName和Password，则仅生效KeyPairName。
        :param pulumi.Input[builtins.str] lifecycle_state: 生命周期状态。取值：Active（活跃）/InActive（非活跃）
        :param pulumi.Input[builtins.str] password: 使用“密码”方式登录实例时，请设置root登录密码：长度限制在8～30之间，密码只能由大写字母、小写字母、数字和特殊字符组成，且必须包含至少三项，特殊字符可以使用：`~!#$%^&*()_-+= |，不能以“/”和“$6$”开头
        :param pulumi.Input[builtins.str] project_name: 伸缩配置创建的实例所属项目，默认为空。一个资源只能归属于一个项目。
               只能包含字母、数字、下划线“_”、点“.”和中划线“-”。
               长度限制在64个字符以内。
        :param pulumi.Input[builtins.str] scaling_configuration_name: 伸缩配置的名称，在同一地域下同一伸缩组内伸缩配置名称唯一。取值:只能以中文、字母开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1 ~ 128个字符。暂不支持特殊字符。
        :param pulumi.Input[builtins.str] scaling_group_id: 伸缩配置所属的伸缩组ID。
        :param pulumi.Input[builtins.str] security_enhancement_strategy: 是否开启安全加固，取值：Active：开启安全加固，仅对公共镜像生效。InActive：关闭安全加固，对所有镜像生效。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: 实例主网卡关联的安全组ID。
        :param pulumi.Input[builtins.str] spot_strategy: 实例的抢占策略。取值：NoSpot（默认）：表示创建正常按量付费实例。SpotAsPriceGo：表示系统自动出价，跟随当前市场实际价格的抢占式实例。SpotWithPriceLimit：表示需要设置出价上限的抢占式实例。
        :param pulumi.Input[builtins.str] user_data: 实例自定义数据。设置的自定义数据必须经过Base64编码，且Base64编码前的自定义数据大小不能超过16KB。不填则默认为空。
        :param pulumi.Input[builtins.str] zone_id: 伸缩配置可用区ID。
        """
        if eip is not None:
            pulumi.set(__self__, "eip", eip)
        if host_name is not None:
            pulumi.set(__self__, "host_name", host_name)
        if hpc_cluster_id is not None:
            pulumi.set(__self__, "hpc_cluster_id", hpc_cluster_id)
        if image_id is not None:
            pulumi.set(__self__, "image_id", image_id)
        if instance_description is not None:
            pulumi.set(__self__, "instance_description", instance_description)
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if instance_type_overrides is not None:
            pulumi.set(__self__, "instance_type_overrides", instance_type_overrides)
        if ipv6_address_count is not None:
            pulumi.set(__self__, "ipv6_address_count", ipv6_address_count)
        if key_pair_name is not None:
            pulumi.set(__self__, "key_pair_name", key_pair_name)
        if lifecycle_state is not None:
            pulumi.set(__self__, "lifecycle_state", lifecycle_state)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if scaling_configuration_name is not None:
            pulumi.set(__self__, "scaling_configuration_name", scaling_configuration_name)
        if scaling_group_id is not None:
            pulumi.set(__self__, "scaling_group_id", scaling_group_id)
        if security_enhancement_strategy is not None:
            pulumi.set(__self__, "security_enhancement_strategy", security_enhancement_strategy)
        if security_group_ids is not None:
            pulumi.set(__self__, "security_group_ids", security_group_ids)
        if spot_strategy is not None:
            pulumi.set(__self__, "spot_strategy", spot_strategy)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if user_data is not None:
            pulumi.set(__self__, "user_data", user_data)
        if volumes is not None:
            pulumi.set(__self__, "volumes", volumes)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter
    def eip(self) -> Optional[pulumi.Input['ScalingConfigurationEipArgs']]:
        """
        公网IP。
        """
        return pulumi.get(self, "eip")

    @eip.setter
    def eip(self, value: Optional[pulumi.Input['ScalingConfigurationEipArgs']]):
        pulumi.set(self, "eip", value)

    @property
    @pulumi.getter(name="hostName")
    def host_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的主机名。取值：Linux实例允许使用点号分隔字符成多段，每段中允许使用字母、数字或中划线“-”。不能以点号“.”或中划线“-”开头或结尾，且不能连续使用点号“.”或中划线“-”。Linux系统的主机名长度限制为2～63个字符。Windows实例允许使用字母、数字或中划线“-”，不能完全是数字。不能以中划线“-”开头或结尾，且不能连续使用中划线“-”。Windows系统的主机名长度限制在2～15个字符。如不填，则遵循以下规则自动生成：结构：iv  - + 初始主机名，例如iv-3tigy72q3u3vj0******。已创建实例保持原主机名生成逻辑，不随实例重启发生变化。初始主机名生成逻辑：Linux：提取实例IDi-之后的全部字符。Windows：提取实例IDi-之后的后12位字符。
        """
        return pulumi.get(self, "host_name")

    @host_name.setter
    def host_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "host_name", value)

    @property
    @pulumi.getter(name="hpcClusterId")
    def hpc_cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属的高性能计算集群的ID。仅当InstanceTypes.N指定为“高性能计算GPU型”时有效。
        """
        return pulumi.get(self, "hpc_cluster_id")

    @hpc_cluster_id.setter
    def hpc_cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "hpc_cluster_id", value)

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像ID，伸缩组自动创建实例时使用的镜像资源。
        """
        return pulumi.get(self, "image_id")

    @image_id.setter
    def image_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_id", value)

    @property
    @pulumi.getter(name="instanceDescription")
    def instance_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的描述，取值：不能以数字、中划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制在0 ~ 255之间。不填默认为空字符串。
        """
        return pulumi.get(self, "instance_description")

    @instance_description.setter
    def instance_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_description", value)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的名称，取值：以字母或中文开头。只能包含中文、字母、数字、下划线“_”、中划线“-”和点号“.”。长度限制为1～128个字符。
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="instanceTypeOverrides")
    def instance_type_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ScalingConfigurationInstanceTypeOverrideArgs']]]]:
        return pulumi.get(self, "instance_type_overrides")

    @instance_type_overrides.setter
    def instance_type_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingConfigurationInstanceTypeOverrideArgs']]]]):
        pulumi.set(self, "instance_type_overrides", value)

    @property
    @pulumi.getter(name="ipv6AddressCount")
    def ipv6_address_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        是否为实例网卡分配IPv6地址。取值：0：不分配IPv6地址。1：分配IPv6地址，系统自动为您分配IPv6网段。
        """
        return pulumi.get(self, "ipv6_address_count")

    @ipv6_address_count.setter
    def ipv6_address_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "ipv6_address_count", value)

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        KeyPairName string 可选 示例值：kp-test-123，使用“SSH密钥对”登录实例时，请输入密钥对的名称。如果同时设置了KeyPairName和Password，则仅生效KeyPairName。
        """
        return pulumi.get(self, "key_pair_name")

    @key_pair_name.setter
    def key_pair_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key_pair_name", value)

    @property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        生命周期状态。取值：Active（活跃）/InActive（非活跃）
        """
        return pulumi.get(self, "lifecycle_state")

    @lifecycle_state.setter
    def lifecycle_state(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "lifecycle_state", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        使用“密码”方式登录实例时，请设置root登录密码：长度限制在8～30之间，密码只能由大写字母、小写字母、数字和特殊字符组成，且必须包含至少三项，特殊字符可以使用：`~!#$%^&*()_-+= |，不能以“/”和“$6$”开头
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩配置创建的实例所属项目，默认为空。一个资源只能归属于一个项目。
        只能包含字母、数字、下划线“_”、点“.”和中划线“-”。
        长度限制在64个字符以内。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="scalingConfigurationName")
    def scaling_configuration_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩配置的名称，在同一地域下同一伸缩组内伸缩配置名称唯一。取值:只能以中文、字母开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1 ~ 128个字符。暂不支持特殊字符。
        """
        return pulumi.get(self, "scaling_configuration_name")

    @scaling_configuration_name.setter
    def scaling_configuration_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scaling_configuration_name", value)

    @property
    @pulumi.getter(name="scalingGroupId")
    def scaling_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩配置所属的伸缩组ID。
        """
        return pulumi.get(self, "scaling_group_id")

    @scaling_group_id.setter
    def scaling_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scaling_group_id", value)

    @property
    @pulumi.getter(name="securityEnhancementStrategy")
    def security_enhancement_strategy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        是否开启安全加固，取值：Active：开启安全加固，仅对公共镜像生效。InActive：关闭安全加固，对所有镜像生效。
        """
        return pulumi.get(self, "security_enhancement_strategy")

    @security_enhancement_strategy.setter
    def security_enhancement_strategy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "security_enhancement_strategy", value)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        实例主网卡关联的安全组ID。
        """
        return pulumi.get(self, "security_group_ids")

    @security_group_ids.setter
    def security_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "security_group_ids", value)

    @property
    @pulumi.getter(name="spotStrategy")
    def spot_strategy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的抢占策略。取值：NoSpot（默认）：表示创建正常按量付费实例。SpotAsPriceGo：表示系统自动出价，跟随当前市场实际价格的抢占式实例。SpotWithPriceLimit：表示需要设置出价上限的抢占式实例。
        """
        return pulumi.get(self, "spot_strategy")

    @spot_strategy.setter
    def spot_strategy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "spot_strategy", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ScalingConfigurationTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingConfigurationTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="userData")
    def user_data(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例自定义数据。设置的自定义数据必须经过Base64编码，且Base64编码前的自定义数据大小不能超过16KB。不填则默认为空。
        """
        return pulumi.get(self, "user_data")

    @user_data.setter
    def user_data(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_data", value)

    @property
    @pulumi.getter
    def volumes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ScalingConfigurationVolumeArgs']]]]:
        return pulumi.get(self, "volumes")

    @volumes.setter
    def volumes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingConfigurationVolumeArgs']]]]):
        pulumi.set(self, "volumes", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩配置可用区ID。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.input_type
class _ScalingConfigurationState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 eip: Optional[pulumi.Input['ScalingConfigurationEipArgs']] = None,
                 host_name: Optional[pulumi.Input[builtins.str]] = None,
                 hpc_cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_charge_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type_overrides: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingConfigurationInstanceTypeOverrideArgs']]]] = None,
                 instance_types: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 ipv6_address_count: Optional[pulumi.Input[builtins.int]] = None,
                 key_pair_name: Optional[pulumi.Input[builtins.str]] = None,
                 lifecycle_state: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 scaling_configuration_id: Optional[pulumi.Input[builtins.str]] = None,
                 scaling_configuration_name: Optional[pulumi.Input[builtins.str]] = None,
                 scaling_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 security_enhancement_strategy: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 spot_strategy: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingConfigurationTagArgs']]]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None,
                 user_data: Optional[pulumi.Input[builtins.str]] = None,
                 volumes: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingConfigurationVolumeArgs']]]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ScalingConfiguration resources.
        :param pulumi.Input[builtins.str] created_at: 资源创建时间(UTC时间)
        :param pulumi.Input['ScalingConfigurationEipArgs'] eip: 公网IP。
        :param pulumi.Input[builtins.str] host_name: 实例的主机名。取值：Linux实例允许使用点号分隔字符成多段，每段中允许使用字母、数字或中划线“-”。不能以点号“.”或中划线“-”开头或结尾，且不能连续使用点号“.”或中划线“-”。Linux系统的主机名长度限制为2～63个字符。Windows实例允许使用字母、数字或中划线“-”，不能完全是数字。不能以中划线“-”开头或结尾，且不能连续使用中划线“-”。Windows系统的主机名长度限制在2～15个字符。如不填，则遵循以下规则自动生成：结构：iv  - + 初始主机名，例如iv-3tigy72q3u3vj0******。已创建实例保持原主机名生成逻辑，不随实例重启发生变化。初始主机名生成逻辑：Linux：提取实例IDi-之后的全部字符。Windows：提取实例IDi-之后的后12位字符。
        :param pulumi.Input[builtins.str] hpc_cluster_id: 实例所属的高性能计算集群的ID。仅当InstanceTypes.N指定为“高性能计算GPU型”时有效。
        :param pulumi.Input[builtins.str] image_id: 镜像ID，伸缩组自动创建实例时使用的镜像资源。
        :param pulumi.Input[builtins.str] instance_charge_type: 实例计费类型。取值：PrePaid（包年包月）/PostPaid（按量付费）
        :param pulumi.Input[builtins.str] instance_description: 实例的描述，取值：不能以数字、中划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制在0 ~ 255之间。不填默认为空字符串。
        :param pulumi.Input[builtins.str] instance_name: 实例的名称，取值：以字母或中文开头。只能包含中文、字母、数字、下划线“_”、中划线“-”和点号“.”。长度限制为1～128个字符。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] instance_types: 实例的计算规格列表。
        :param pulumi.Input[builtins.int] ipv6_address_count: 是否为实例网卡分配IPv6地址。取值：0：不分配IPv6地址。1：分配IPv6地址，系统自动为您分配IPv6网段。
        :param pulumi.Input[builtins.str] key_pair_name: KeyPairName string 可选 示例值：kp-test-123，使用“SSH密钥对”登录实例时，请输入密钥对的名称。如果同时设置了KeyPairName和Password，则仅生效KeyPairName。
        :param pulumi.Input[builtins.str] lifecycle_state: 生命周期状态。取值：Active（活跃）/InActive（非活跃）
        :param pulumi.Input[builtins.str] password: 使用“密码”方式登录实例时，请设置root登录密码：长度限制在8～30之间，密码只能由大写字母、小写字母、数字和特殊字符组成，且必须包含至少三项，特殊字符可以使用：`~!#$%^&*()_-+= |，不能以“/”和“$6$”开头
        :param pulumi.Input[builtins.str] project_name: 伸缩配置创建的实例所属项目，默认为空。一个资源只能归属于一个项目。
               只能包含字母、数字、下划线“_”、点“.”和中划线“-”。
               长度限制在64个字符以内。
        :param pulumi.Input[builtins.str] scaling_configuration_id: 伸缩配置ID。
        :param pulumi.Input[builtins.str] scaling_configuration_name: 伸缩配置的名称，在同一地域下同一伸缩组内伸缩配置名称唯一。取值:只能以中文、字母开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1 ~ 128个字符。暂不支持特殊字符。
        :param pulumi.Input[builtins.str] scaling_group_id: 伸缩配置所属的伸缩组ID。
        :param pulumi.Input[builtins.str] security_enhancement_strategy: 是否开启安全加固，取值：Active：开启安全加固，仅对公共镜像生效。InActive：关闭安全加固，对所有镜像生效。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: 实例主网卡关联的安全组ID。
        :param pulumi.Input[builtins.str] spot_strategy: 实例的抢占策略。取值：NoSpot（默认）：表示创建正常按量付费实例。SpotAsPriceGo：表示系统自动出价，跟随当前市场实际价格的抢占式实例。SpotWithPriceLimit：表示需要设置出价上限的抢占式实例。
        :param pulumi.Input[builtins.str] updated_at: 资源更新时间(UTC时间)
        :param pulumi.Input[builtins.str] user_data: 实例自定义数据。设置的自定义数据必须经过Base64编码，且Base64编码前的自定义数据大小不能超过16KB。不填则默认为空。
        :param pulumi.Input[builtins.str] zone_id: 伸缩配置可用区ID。
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if eip is not None:
            pulumi.set(__self__, "eip", eip)
        if host_name is not None:
            pulumi.set(__self__, "host_name", host_name)
        if hpc_cluster_id is not None:
            pulumi.set(__self__, "hpc_cluster_id", hpc_cluster_id)
        if image_id is not None:
            pulumi.set(__self__, "image_id", image_id)
        if instance_charge_type is not None:
            pulumi.set(__self__, "instance_charge_type", instance_charge_type)
        if instance_description is not None:
            pulumi.set(__self__, "instance_description", instance_description)
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if instance_type_overrides is not None:
            pulumi.set(__self__, "instance_type_overrides", instance_type_overrides)
        if instance_types is not None:
            pulumi.set(__self__, "instance_types", instance_types)
        if ipv6_address_count is not None:
            pulumi.set(__self__, "ipv6_address_count", ipv6_address_count)
        if key_pair_name is not None:
            pulumi.set(__self__, "key_pair_name", key_pair_name)
        if lifecycle_state is not None:
            pulumi.set(__self__, "lifecycle_state", lifecycle_state)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if scaling_configuration_id is not None:
            pulumi.set(__self__, "scaling_configuration_id", scaling_configuration_id)
        if scaling_configuration_name is not None:
            pulumi.set(__self__, "scaling_configuration_name", scaling_configuration_name)
        if scaling_group_id is not None:
            pulumi.set(__self__, "scaling_group_id", scaling_group_id)
        if security_enhancement_strategy is not None:
            pulumi.set(__self__, "security_enhancement_strategy", security_enhancement_strategy)
        if security_group_ids is not None:
            pulumi.set(__self__, "security_group_ids", security_group_ids)
        if spot_strategy is not None:
            pulumi.set(__self__, "spot_strategy", spot_strategy)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if user_data is not None:
            pulumi.set(__self__, "user_data", user_data)
        if volumes is not None:
            pulumi.set(__self__, "volumes", volumes)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        资源创建时间(UTC时间)
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def eip(self) -> Optional[pulumi.Input['ScalingConfigurationEipArgs']]:
        """
        公网IP。
        """
        return pulumi.get(self, "eip")

    @eip.setter
    def eip(self, value: Optional[pulumi.Input['ScalingConfigurationEipArgs']]):
        pulumi.set(self, "eip", value)

    @property
    @pulumi.getter(name="hostName")
    def host_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的主机名。取值：Linux实例允许使用点号分隔字符成多段，每段中允许使用字母、数字或中划线“-”。不能以点号“.”或中划线“-”开头或结尾，且不能连续使用点号“.”或中划线“-”。Linux系统的主机名长度限制为2～63个字符。Windows实例允许使用字母、数字或中划线“-”，不能完全是数字。不能以中划线“-”开头或结尾，且不能连续使用中划线“-”。Windows系统的主机名长度限制在2～15个字符。如不填，则遵循以下规则自动生成：结构：iv  - + 初始主机名，例如iv-3tigy72q3u3vj0******。已创建实例保持原主机名生成逻辑，不随实例重启发生变化。初始主机名生成逻辑：Linux：提取实例IDi-之后的全部字符。Windows：提取实例IDi-之后的后12位字符。
        """
        return pulumi.get(self, "host_name")

    @host_name.setter
    def host_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "host_name", value)

    @property
    @pulumi.getter(name="hpcClusterId")
    def hpc_cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属的高性能计算集群的ID。仅当InstanceTypes.N指定为“高性能计算GPU型”时有效。
        """
        return pulumi.get(self, "hpc_cluster_id")

    @hpc_cluster_id.setter
    def hpc_cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "hpc_cluster_id", value)

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像ID，伸缩组自动创建实例时使用的镜像资源。
        """
        return pulumi.get(self, "image_id")

    @image_id.setter
    def image_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_id", value)

    @property
    @pulumi.getter(name="instanceChargeType")
    def instance_charge_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例计费类型。取值：PrePaid（包年包月）/PostPaid（按量付费）
        """
        return pulumi.get(self, "instance_charge_type")

    @instance_charge_type.setter
    def instance_charge_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_charge_type", value)

    @property
    @pulumi.getter(name="instanceDescription")
    def instance_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的描述，取值：不能以数字、中划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制在0 ~ 255之间。不填默认为空字符串。
        """
        return pulumi.get(self, "instance_description")

    @instance_description.setter
    def instance_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_description", value)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的名称，取值：以字母或中文开头。只能包含中文、字母、数字、下划线“_”、中划线“-”和点号“.”。长度限制为1～128个字符。
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="instanceTypeOverrides")
    def instance_type_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ScalingConfigurationInstanceTypeOverrideArgs']]]]:
        return pulumi.get(self, "instance_type_overrides")

    @instance_type_overrides.setter
    def instance_type_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingConfigurationInstanceTypeOverrideArgs']]]]):
        pulumi.set(self, "instance_type_overrides", value)

    @property
    @pulumi.getter(name="instanceTypes")
    def instance_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        实例的计算规格列表。
        """
        return pulumi.get(self, "instance_types")

    @instance_types.setter
    def instance_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "instance_types", value)

    @property
    @pulumi.getter(name="ipv6AddressCount")
    def ipv6_address_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        是否为实例网卡分配IPv6地址。取值：0：不分配IPv6地址。1：分配IPv6地址，系统自动为您分配IPv6网段。
        """
        return pulumi.get(self, "ipv6_address_count")

    @ipv6_address_count.setter
    def ipv6_address_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "ipv6_address_count", value)

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        KeyPairName string 可选 示例值：kp-test-123，使用“SSH密钥对”登录实例时，请输入密钥对的名称。如果同时设置了KeyPairName和Password，则仅生效KeyPairName。
        """
        return pulumi.get(self, "key_pair_name")

    @key_pair_name.setter
    def key_pair_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key_pair_name", value)

    @property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        生命周期状态。取值：Active（活跃）/InActive（非活跃）
        """
        return pulumi.get(self, "lifecycle_state")

    @lifecycle_state.setter
    def lifecycle_state(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "lifecycle_state", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        使用“密码”方式登录实例时，请设置root登录密码：长度限制在8～30之间，密码只能由大写字母、小写字母、数字和特殊字符组成，且必须包含至少三项，特殊字符可以使用：`~!#$%^&*()_-+= |，不能以“/”和“$6$”开头
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩配置创建的实例所属项目，默认为空。一个资源只能归属于一个项目。
        只能包含字母、数字、下划线“_”、点“.”和中划线“-”。
        长度限制在64个字符以内。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="scalingConfigurationId")
    def scaling_configuration_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩配置ID。
        """
        return pulumi.get(self, "scaling_configuration_id")

    @scaling_configuration_id.setter
    def scaling_configuration_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scaling_configuration_id", value)

    @property
    @pulumi.getter(name="scalingConfigurationName")
    def scaling_configuration_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩配置的名称，在同一地域下同一伸缩组内伸缩配置名称唯一。取值:只能以中文、字母开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1 ~ 128个字符。暂不支持特殊字符。
        """
        return pulumi.get(self, "scaling_configuration_name")

    @scaling_configuration_name.setter
    def scaling_configuration_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scaling_configuration_name", value)

    @property
    @pulumi.getter(name="scalingGroupId")
    def scaling_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩配置所属的伸缩组ID。
        """
        return pulumi.get(self, "scaling_group_id")

    @scaling_group_id.setter
    def scaling_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scaling_group_id", value)

    @property
    @pulumi.getter(name="securityEnhancementStrategy")
    def security_enhancement_strategy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        是否开启安全加固，取值：Active：开启安全加固，仅对公共镜像生效。InActive：关闭安全加固，对所有镜像生效。
        """
        return pulumi.get(self, "security_enhancement_strategy")

    @security_enhancement_strategy.setter
    def security_enhancement_strategy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "security_enhancement_strategy", value)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        实例主网卡关联的安全组ID。
        """
        return pulumi.get(self, "security_group_ids")

    @security_group_ids.setter
    def security_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "security_group_ids", value)

    @property
    @pulumi.getter(name="spotStrategy")
    def spot_strategy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的抢占策略。取值：NoSpot（默认）：表示创建正常按量付费实例。SpotAsPriceGo：表示系统自动出价，跟随当前市场实际价格的抢占式实例。SpotWithPriceLimit：表示需要设置出价上限的抢占式实例。
        """
        return pulumi.get(self, "spot_strategy")

    @spot_strategy.setter
    def spot_strategy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "spot_strategy", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ScalingConfigurationTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingConfigurationTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        资源更新时间(UTC时间)
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter(name="userData")
    def user_data(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例自定义数据。设置的自定义数据必须经过Base64编码，且Base64编码前的自定义数据大小不能超过16KB。不填则默认为空。
        """
        return pulumi.get(self, "user_data")

    @user_data.setter
    def user_data(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_data", value)

    @property
    @pulumi.getter
    def volumes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ScalingConfigurationVolumeArgs']]]]:
        return pulumi.get(self, "volumes")

    @volumes.setter
    def volumes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingConfigurationVolumeArgs']]]]):
        pulumi.set(self, "volumes", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩配置可用区ID。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.type_token("bytepluscc:autoscaling/scalingConfiguration:ScalingConfiguration")
class ScalingConfiguration(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 eip: Optional[pulumi.Input[Union['ScalingConfigurationEipArgs', 'ScalingConfigurationEipArgsDict']]] = None,
                 host_name: Optional[pulumi.Input[builtins.str]] = None,
                 hpc_cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ScalingConfigurationInstanceTypeOverrideArgs', 'ScalingConfigurationInstanceTypeOverrideArgsDict']]]]] = None,
                 ipv6_address_count: Optional[pulumi.Input[builtins.int]] = None,
                 key_pair_name: Optional[pulumi.Input[builtins.str]] = None,
                 lifecycle_state: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 scaling_configuration_name: Optional[pulumi.Input[builtins.str]] = None,
                 scaling_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 security_enhancement_strategy: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 spot_strategy: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ScalingConfigurationTagArgs', 'ScalingConfigurationTagArgsDict']]]]] = None,
                 user_data: Optional[pulumi.Input[builtins.str]] = None,
                 volumes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ScalingConfigurationVolumeArgs', 'ScalingConfigurationVolumeArgsDict']]]]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        用于定义伸缩组中的实例配置，包括计算、内存、网络、存储、安全等，伸缩组扩容时，会按照此处的配置来源创建新实例。

        ## Import

        ```sh
        $ pulumi import bytepluscc:autoscaling/scalingConfiguration:ScalingConfiguration example "scaling_configuration_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ScalingConfigurationEipArgs', 'ScalingConfigurationEipArgsDict']] eip: 公网IP。
        :param pulumi.Input[builtins.str] host_name: 实例的主机名。取值：Linux实例允许使用点号分隔字符成多段，每段中允许使用字母、数字或中划线“-”。不能以点号“.”或中划线“-”开头或结尾，且不能连续使用点号“.”或中划线“-”。Linux系统的主机名长度限制为2～63个字符。Windows实例允许使用字母、数字或中划线“-”，不能完全是数字。不能以中划线“-”开头或结尾，且不能连续使用中划线“-”。Windows系统的主机名长度限制在2～15个字符。如不填，则遵循以下规则自动生成：结构：iv  - + 初始主机名，例如iv-3tigy72q3u3vj0******。已创建实例保持原主机名生成逻辑，不随实例重启发生变化。初始主机名生成逻辑：Linux：提取实例IDi-之后的全部字符。Windows：提取实例IDi-之后的后12位字符。
        :param pulumi.Input[builtins.str] hpc_cluster_id: 实例所属的高性能计算集群的ID。仅当InstanceTypes.N指定为“高性能计算GPU型”时有效。
        :param pulumi.Input[builtins.str] image_id: 镜像ID，伸缩组自动创建实例时使用的镜像资源。
        :param pulumi.Input[builtins.str] instance_description: 实例的描述，取值：不能以数字、中划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制在0 ~ 255之间。不填默认为空字符串。
        :param pulumi.Input[builtins.str] instance_name: 实例的名称，取值：以字母或中文开头。只能包含中文、字母、数字、下划线“_”、中划线“-”和点号“.”。长度限制为1～128个字符。
        :param pulumi.Input[builtins.int] ipv6_address_count: 是否为实例网卡分配IPv6地址。取值：0：不分配IPv6地址。1：分配IPv6地址，系统自动为您分配IPv6网段。
        :param pulumi.Input[builtins.str] key_pair_name: KeyPairName string 可选 示例值：kp-test-123，使用“SSH密钥对”登录实例时，请输入密钥对的名称。如果同时设置了KeyPairName和Password，则仅生效KeyPairName。
        :param pulumi.Input[builtins.str] lifecycle_state: 生命周期状态。取值：Active（活跃）/InActive（非活跃）
        :param pulumi.Input[builtins.str] password: 使用“密码”方式登录实例时，请设置root登录密码：长度限制在8～30之间，密码只能由大写字母、小写字母、数字和特殊字符组成，且必须包含至少三项，特殊字符可以使用：`~!#$%^&*()_-+= |，不能以“/”和“$6$”开头
        :param pulumi.Input[builtins.str] project_name: 伸缩配置创建的实例所属项目，默认为空。一个资源只能归属于一个项目。
               只能包含字母、数字、下划线“_”、点“.”和中划线“-”。
               长度限制在64个字符以内。
        :param pulumi.Input[builtins.str] scaling_configuration_name: 伸缩配置的名称，在同一地域下同一伸缩组内伸缩配置名称唯一。取值:只能以中文、字母开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1 ~ 128个字符。暂不支持特殊字符。
        :param pulumi.Input[builtins.str] scaling_group_id: 伸缩配置所属的伸缩组ID。
        :param pulumi.Input[builtins.str] security_enhancement_strategy: 是否开启安全加固，取值：Active：开启安全加固，仅对公共镜像生效。InActive：关闭安全加固，对所有镜像生效。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: 实例主网卡关联的安全组ID。
        :param pulumi.Input[builtins.str] spot_strategy: 实例的抢占策略。取值：NoSpot（默认）：表示创建正常按量付费实例。SpotAsPriceGo：表示系统自动出价，跟随当前市场实际价格的抢占式实例。SpotWithPriceLimit：表示需要设置出价上限的抢占式实例。
        :param pulumi.Input[builtins.str] user_data: 实例自定义数据。设置的自定义数据必须经过Base64编码，且Base64编码前的自定义数据大小不能超过16KB。不填则默认为空。
        :param pulumi.Input[builtins.str] zone_id: 伸缩配置可用区ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ScalingConfigurationArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        用于定义伸缩组中的实例配置，包括计算、内存、网络、存储、安全等，伸缩组扩容时，会按照此处的配置来源创建新实例。

        ## Import

        ```sh
        $ pulumi import bytepluscc:autoscaling/scalingConfiguration:ScalingConfiguration example "scaling_configuration_id"
        ```

        :param str resource_name: The name of the resource.
        :param ScalingConfigurationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ScalingConfigurationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 eip: Optional[pulumi.Input[Union['ScalingConfigurationEipArgs', 'ScalingConfigurationEipArgsDict']]] = None,
                 host_name: Optional[pulumi.Input[builtins.str]] = None,
                 hpc_cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ScalingConfigurationInstanceTypeOverrideArgs', 'ScalingConfigurationInstanceTypeOverrideArgsDict']]]]] = None,
                 ipv6_address_count: Optional[pulumi.Input[builtins.int]] = None,
                 key_pair_name: Optional[pulumi.Input[builtins.str]] = None,
                 lifecycle_state: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 scaling_configuration_name: Optional[pulumi.Input[builtins.str]] = None,
                 scaling_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 security_enhancement_strategy: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 spot_strategy: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ScalingConfigurationTagArgs', 'ScalingConfigurationTagArgsDict']]]]] = None,
                 user_data: Optional[pulumi.Input[builtins.str]] = None,
                 volumes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ScalingConfigurationVolumeArgs', 'ScalingConfigurationVolumeArgsDict']]]]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ScalingConfigurationArgs.__new__(ScalingConfigurationArgs)

            __props__.__dict__["eip"] = eip
            __props__.__dict__["host_name"] = host_name
            __props__.__dict__["hpc_cluster_id"] = hpc_cluster_id
            __props__.__dict__["image_id"] = image_id
            __props__.__dict__["instance_description"] = instance_description
            __props__.__dict__["instance_name"] = instance_name
            __props__.__dict__["instance_type_overrides"] = instance_type_overrides
            __props__.__dict__["ipv6_address_count"] = ipv6_address_count
            __props__.__dict__["key_pair_name"] = key_pair_name
            __props__.__dict__["lifecycle_state"] = lifecycle_state
            __props__.__dict__["password"] = password
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["scaling_configuration_name"] = scaling_configuration_name
            __props__.__dict__["scaling_group_id"] = scaling_group_id
            __props__.__dict__["security_enhancement_strategy"] = security_enhancement_strategy
            __props__.__dict__["security_group_ids"] = security_group_ids
            __props__.__dict__["spot_strategy"] = spot_strategy
            __props__.__dict__["tags"] = tags
            __props__.__dict__["user_data"] = user_data
            __props__.__dict__["volumes"] = volumes
            __props__.__dict__["zone_id"] = zone_id
            __props__.__dict__["created_at"] = None
            __props__.__dict__["instance_charge_type"] = None
            __props__.__dict__["instance_types"] = None
            __props__.__dict__["scaling_configuration_id"] = None
            __props__.__dict__["updated_at"] = None
        super(ScalingConfiguration, __self__).__init__(
            'bytepluscc:autoscaling/scalingConfiguration:ScalingConfiguration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            eip: Optional[pulumi.Input[Union['ScalingConfigurationEipArgs', 'ScalingConfigurationEipArgsDict']]] = None,
            host_name: Optional[pulumi.Input[builtins.str]] = None,
            hpc_cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            image_id: Optional[pulumi.Input[builtins.str]] = None,
            instance_charge_type: Optional[pulumi.Input[builtins.str]] = None,
            instance_description: Optional[pulumi.Input[builtins.str]] = None,
            instance_name: Optional[pulumi.Input[builtins.str]] = None,
            instance_type_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ScalingConfigurationInstanceTypeOverrideArgs', 'ScalingConfigurationInstanceTypeOverrideArgsDict']]]]] = None,
            instance_types: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            ipv6_address_count: Optional[pulumi.Input[builtins.int]] = None,
            key_pair_name: Optional[pulumi.Input[builtins.str]] = None,
            lifecycle_state: Optional[pulumi.Input[builtins.str]] = None,
            password: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            scaling_configuration_id: Optional[pulumi.Input[builtins.str]] = None,
            scaling_configuration_name: Optional[pulumi.Input[builtins.str]] = None,
            scaling_group_id: Optional[pulumi.Input[builtins.str]] = None,
            security_enhancement_strategy: Optional[pulumi.Input[builtins.str]] = None,
            security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            spot_strategy: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ScalingConfigurationTagArgs', 'ScalingConfigurationTagArgsDict']]]]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None,
            user_data: Optional[pulumi.Input[builtins.str]] = None,
            volumes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ScalingConfigurationVolumeArgs', 'ScalingConfigurationVolumeArgsDict']]]]] = None,
            zone_id: Optional[pulumi.Input[builtins.str]] = None) -> 'ScalingConfiguration':
        """
        Get an existing ScalingConfiguration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_at: 资源创建时间(UTC时间)
        :param pulumi.Input[Union['ScalingConfigurationEipArgs', 'ScalingConfigurationEipArgsDict']] eip: 公网IP。
        :param pulumi.Input[builtins.str] host_name: 实例的主机名。取值：Linux实例允许使用点号分隔字符成多段，每段中允许使用字母、数字或中划线“-”。不能以点号“.”或中划线“-”开头或结尾，且不能连续使用点号“.”或中划线“-”。Linux系统的主机名长度限制为2～63个字符。Windows实例允许使用字母、数字或中划线“-”，不能完全是数字。不能以中划线“-”开头或结尾，且不能连续使用中划线“-”。Windows系统的主机名长度限制在2～15个字符。如不填，则遵循以下规则自动生成：结构：iv  - + 初始主机名，例如iv-3tigy72q3u3vj0******。已创建实例保持原主机名生成逻辑，不随实例重启发生变化。初始主机名生成逻辑：Linux：提取实例IDi-之后的全部字符。Windows：提取实例IDi-之后的后12位字符。
        :param pulumi.Input[builtins.str] hpc_cluster_id: 实例所属的高性能计算集群的ID。仅当InstanceTypes.N指定为“高性能计算GPU型”时有效。
        :param pulumi.Input[builtins.str] image_id: 镜像ID，伸缩组自动创建实例时使用的镜像资源。
        :param pulumi.Input[builtins.str] instance_charge_type: 实例计费类型。取值：PrePaid（包年包月）/PostPaid（按量付费）
        :param pulumi.Input[builtins.str] instance_description: 实例的描述，取值：不能以数字、中划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制在0 ~ 255之间。不填默认为空字符串。
        :param pulumi.Input[builtins.str] instance_name: 实例的名称，取值：以字母或中文开头。只能包含中文、字母、数字、下划线“_”、中划线“-”和点号“.”。长度限制为1～128个字符。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] instance_types: 实例的计算规格列表。
        :param pulumi.Input[builtins.int] ipv6_address_count: 是否为实例网卡分配IPv6地址。取值：0：不分配IPv6地址。1：分配IPv6地址，系统自动为您分配IPv6网段。
        :param pulumi.Input[builtins.str] key_pair_name: KeyPairName string 可选 示例值：kp-test-123，使用“SSH密钥对”登录实例时，请输入密钥对的名称。如果同时设置了KeyPairName和Password，则仅生效KeyPairName。
        :param pulumi.Input[builtins.str] lifecycle_state: 生命周期状态。取值：Active（活跃）/InActive（非活跃）
        :param pulumi.Input[builtins.str] password: 使用“密码”方式登录实例时，请设置root登录密码：长度限制在8～30之间，密码只能由大写字母、小写字母、数字和特殊字符组成，且必须包含至少三项，特殊字符可以使用：`~!#$%^&*()_-+= |，不能以“/”和“$6$”开头
        :param pulumi.Input[builtins.str] project_name: 伸缩配置创建的实例所属项目，默认为空。一个资源只能归属于一个项目。
               只能包含字母、数字、下划线“_”、点“.”和中划线“-”。
               长度限制在64个字符以内。
        :param pulumi.Input[builtins.str] scaling_configuration_id: 伸缩配置ID。
        :param pulumi.Input[builtins.str] scaling_configuration_name: 伸缩配置的名称，在同一地域下同一伸缩组内伸缩配置名称唯一。取值:只能以中文、字母开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1 ~ 128个字符。暂不支持特殊字符。
        :param pulumi.Input[builtins.str] scaling_group_id: 伸缩配置所属的伸缩组ID。
        :param pulumi.Input[builtins.str] security_enhancement_strategy: 是否开启安全加固，取值：Active：开启安全加固，仅对公共镜像生效。InActive：关闭安全加固，对所有镜像生效。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: 实例主网卡关联的安全组ID。
        :param pulumi.Input[builtins.str] spot_strategy: 实例的抢占策略。取值：NoSpot（默认）：表示创建正常按量付费实例。SpotAsPriceGo：表示系统自动出价，跟随当前市场实际价格的抢占式实例。SpotWithPriceLimit：表示需要设置出价上限的抢占式实例。
        :param pulumi.Input[builtins.str] updated_at: 资源更新时间(UTC时间)
        :param pulumi.Input[builtins.str] user_data: 实例自定义数据。设置的自定义数据必须经过Base64编码，且Base64编码前的自定义数据大小不能超过16KB。不填则默认为空。
        :param pulumi.Input[builtins.str] zone_id: 伸缩配置可用区ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ScalingConfigurationState.__new__(_ScalingConfigurationState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["eip"] = eip
        __props__.__dict__["host_name"] = host_name
        __props__.__dict__["hpc_cluster_id"] = hpc_cluster_id
        __props__.__dict__["image_id"] = image_id
        __props__.__dict__["instance_charge_type"] = instance_charge_type
        __props__.__dict__["instance_description"] = instance_description
        __props__.__dict__["instance_name"] = instance_name
        __props__.__dict__["instance_type_overrides"] = instance_type_overrides
        __props__.__dict__["instance_types"] = instance_types
        __props__.__dict__["ipv6_address_count"] = ipv6_address_count
        __props__.__dict__["key_pair_name"] = key_pair_name
        __props__.__dict__["lifecycle_state"] = lifecycle_state
        __props__.__dict__["password"] = password
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["scaling_configuration_id"] = scaling_configuration_id
        __props__.__dict__["scaling_configuration_name"] = scaling_configuration_name
        __props__.__dict__["scaling_group_id"] = scaling_group_id
        __props__.__dict__["security_enhancement_strategy"] = security_enhancement_strategy
        __props__.__dict__["security_group_ids"] = security_group_ids
        __props__.__dict__["spot_strategy"] = spot_strategy
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["user_data"] = user_data
        __props__.__dict__["volumes"] = volumes
        __props__.__dict__["zone_id"] = zone_id
        return ScalingConfiguration(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        资源创建时间(UTC时间)
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def eip(self) -> pulumi.Output['outputs.ScalingConfigurationEip']:
        """
        公网IP。
        """
        return pulumi.get(self, "eip")

    @property
    @pulumi.getter(name="hostName")
    def host_name(self) -> pulumi.Output[builtins.str]:
        """
        实例的主机名。取值：Linux实例允许使用点号分隔字符成多段，每段中允许使用字母、数字或中划线“-”。不能以点号“.”或中划线“-”开头或结尾，且不能连续使用点号“.”或中划线“-”。Linux系统的主机名长度限制为2～63个字符。Windows实例允许使用字母、数字或中划线“-”，不能完全是数字。不能以中划线“-”开头或结尾，且不能连续使用中划线“-”。Windows系统的主机名长度限制在2～15个字符。如不填，则遵循以下规则自动生成：结构：iv  - + 初始主机名，例如iv-3tigy72q3u3vj0******。已创建实例保持原主机名生成逻辑，不随实例重启发生变化。初始主机名生成逻辑：Linux：提取实例IDi-之后的全部字符。Windows：提取实例IDi-之后的后12位字符。
        """
        return pulumi.get(self, "host_name")

    @property
    @pulumi.getter(name="hpcClusterId")
    def hpc_cluster_id(self) -> pulumi.Output[builtins.str]:
        """
        实例所属的高性能计算集群的ID。仅当InstanceTypes.N指定为“高性能计算GPU型”时有效。
        """
        return pulumi.get(self, "hpc_cluster_id")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> pulumi.Output[builtins.str]:
        """
        镜像ID，伸缩组自动创建实例时使用的镜像资源。
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="instanceChargeType")
    def instance_charge_type(self) -> pulumi.Output[builtins.str]:
        """
        实例计费类型。取值：PrePaid（包年包月）/PostPaid（按量付费）
        """
        return pulumi.get(self, "instance_charge_type")

    @property
    @pulumi.getter(name="instanceDescription")
    def instance_description(self) -> pulumi.Output[builtins.str]:
        """
        实例的描述，取值：不能以数字、中划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制在0 ~ 255之间。不填默认为空字符串。
        """
        return pulumi.get(self, "instance_description")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> pulumi.Output[builtins.str]:
        """
        实例的名称，取值：以字母或中文开头。只能包含中文、字母、数字、下划线“_”、中划线“-”和点号“.”。长度限制为1～128个字符。
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="instanceTypeOverrides")
    def instance_type_overrides(self) -> pulumi.Output[Sequence['outputs.ScalingConfigurationInstanceTypeOverride']]:
        return pulumi.get(self, "instance_type_overrides")

    @property
    @pulumi.getter(name="instanceTypes")
    def instance_types(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        实例的计算规格列表。
        """
        return pulumi.get(self, "instance_types")

    @property
    @pulumi.getter(name="ipv6AddressCount")
    def ipv6_address_count(self) -> pulumi.Output[builtins.int]:
        """
        是否为实例网卡分配IPv6地址。取值：0：不分配IPv6地址。1：分配IPv6地址，系统自动为您分配IPv6网段。
        """
        return pulumi.get(self, "ipv6_address_count")

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> pulumi.Output[builtins.str]:
        """
        KeyPairName string 可选 示例值：kp-test-123，使用“SSH密钥对”登录实例时，请输入密钥对的名称。如果同时设置了KeyPairName和Password，则仅生效KeyPairName。
        """
        return pulumi.get(self, "key_pair_name")

    @property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> pulumi.Output[builtins.str]:
        """
        生命周期状态。取值：Active（活跃）/InActive（非活跃）
        """
        return pulumi.get(self, "lifecycle_state")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[builtins.str]:
        """
        使用“密码”方式登录实例时，请设置root登录密码：长度限制在8～30之间，密码只能由大写字母、小写字母、数字和特殊字符组成，且必须包含至少三项，特殊字符可以使用：`~!#$%^&*()_-+= |，不能以“/”和“$6$”开头
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        伸缩配置创建的实例所属项目，默认为空。一个资源只能归属于一个项目。
        只能包含字母、数字、下划线“_”、点“.”和中划线“-”。
        长度限制在64个字符以内。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="scalingConfigurationId")
    def scaling_configuration_id(self) -> pulumi.Output[builtins.str]:
        """
        伸缩配置ID。
        """
        return pulumi.get(self, "scaling_configuration_id")

    @property
    @pulumi.getter(name="scalingConfigurationName")
    def scaling_configuration_name(self) -> pulumi.Output[builtins.str]:
        """
        伸缩配置的名称，在同一地域下同一伸缩组内伸缩配置名称唯一。取值:只能以中文、字母开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1 ~ 128个字符。暂不支持特殊字符。
        """
        return pulumi.get(self, "scaling_configuration_name")

    @property
    @pulumi.getter(name="scalingGroupId")
    def scaling_group_id(self) -> pulumi.Output[builtins.str]:
        """
        伸缩配置所属的伸缩组ID。
        """
        return pulumi.get(self, "scaling_group_id")

    @property
    @pulumi.getter(name="securityEnhancementStrategy")
    def security_enhancement_strategy(self) -> pulumi.Output[builtins.str]:
        """
        是否开启安全加固，取值：Active：开启安全加固，仅对公共镜像生效。InActive：关闭安全加固，对所有镜像生效。
        """
        return pulumi.get(self, "security_enhancement_strategy")

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        实例主网卡关联的安全组ID。
        """
        return pulumi.get(self, "security_group_ids")

    @property
    @pulumi.getter(name="spotStrategy")
    def spot_strategy(self) -> pulumi.Output[builtins.str]:
        """
        实例的抢占策略。取值：NoSpot（默认）：表示创建正常按量付费实例。SpotAsPriceGo：表示系统自动出价，跟随当前市场实际价格的抢占式实例。SpotWithPriceLimit：表示需要设置出价上限的抢占式实例。
        """
        return pulumi.get(self, "spot_strategy")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.ScalingConfigurationTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        资源更新时间(UTC时间)
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="userData")
    def user_data(self) -> pulumi.Output[builtins.str]:
        """
        实例自定义数据。设置的自定义数据必须经过Base64编码，且Base64编码前的自定义数据大小不能超过16KB。不填则默认为空。
        """
        return pulumi.get(self, "user_data")

    @property
    @pulumi.getter
    def volumes(self) -> pulumi.Output[Sequence['outputs.ScalingConfigurationVolume']]:
        return pulumi.get(self, "volumes")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[builtins.str]:
        """
        伸缩配置可用区ID。
        """
        return pulumi.get(self, "zone_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ImageArgs', 'Image']

@pulumi.input_type
class ImageArgs:
    def __init__(__self__, *,
                 image_name: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 share_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 snapshot_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ImageTagArgs']]]] = None):
        """
        The set of arguments for constructing a Image resource.
        :param pulumi.Input[builtins.str] image_name: 镜像名称。必须以字母、汉字开头。只能包含中文、字母、数字、下划线“_”、中划线“-”、英文句号“.”。长度限制为1 ~ 128个字符。
        :param pulumi.Input[builtins.str] description: 镜像描述。必须以字母、汉字开头。只能包含中文、字母、数字、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、英文句号“.”、中文逗号“，”、中文句号“。”和空格。长度限制为0～255个字符。不填默认为空。
        :param pulumi.Input[builtins.str] instance_id: 实例ID。本参数与SnapshotId、SnapshotGroupId参数，三选一必填。
        :param pulumi.Input[builtins.str] project_name: 资源所属项目。调用接口账号若仅拥有部分项目权限时必须传入有权限的项目信息。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] share_permissions: 镜像共享的账户
        :param pulumi.Input[builtins.str] snapshot_group_id: 快照一致性组ID，表示使用快照一致性组创建自定义镜像。本参数与SnapshotId、InstanceId参数，三选一必填。
        :param pulumi.Input[builtins.str] snapshot_id: 系统盘快照ID，表示使用系统盘快照创建自定义镜像。本参数与InstanceId、SnapshotGroupId参数，三选一必填。
        """
        pulumi.set(__self__, "image_name", image_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if share_permissions is not None:
            pulumi.set(__self__, "share_permissions", share_permissions)
        if snapshot_group_id is not None:
            pulumi.set(__self__, "snapshot_group_id", snapshot_group_id)
        if snapshot_id is not None:
            pulumi.set(__self__, "snapshot_id", snapshot_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="imageName")
    def image_name(self) -> pulumi.Input[builtins.str]:
        """
        镜像名称。必须以字母、汉字开头。只能包含中文、字母、数字、下划线“_”、中划线“-”、英文句号“.”。长度限制为1 ~ 128个字符。
        """
        return pulumi.get(self, "image_name")

    @image_name.setter
    def image_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "image_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像描述。必须以字母、汉字开头。只能包含中文、字母、数字、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、英文句号“.”、中文逗号“，”、中文句号“。”和空格。长度限制为0～255个字符。不填默认为空。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例ID。本参数与SnapshotId、SnapshotGroupId参数，三选一必填。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        资源所属项目。调用接口账号若仅拥有部分项目权限时必须传入有权限的项目信息。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="sharePermissions")
    def share_permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        镜像共享的账户
        """
        return pulumi.get(self, "share_permissions")

    @share_permissions.setter
    def share_permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "share_permissions", value)

    @property
    @pulumi.getter(name="snapshotGroupId")
    def snapshot_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        快照一致性组ID，表示使用快照一致性组创建自定义镜像。本参数与SnapshotId、InstanceId参数，三选一必填。
        """
        return pulumi.get(self, "snapshot_group_id")

    @snapshot_group_id.setter
    def snapshot_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "snapshot_group_id", value)

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        系统盘快照ID，表示使用系统盘快照创建自定义镜像。本参数与InstanceId、SnapshotGroupId参数，三选一必填。
        """
        return pulumi.get(self, "snapshot_id")

    @snapshot_id.setter
    def snapshot_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "snapshot_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ImageTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ImageTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ImageState:
    def __init__(__self__, *,
                 architecture: Optional[pulumi.Input[builtins.str]] = None,
                 boot_mode: Optional[pulumi.Input[builtins.str]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 detection_results: Optional[pulumi.Input['ImageDetectionResultsArgs']] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 image_name: Optional[pulumi.Input[builtins.str]] = None,
                 image_owner_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 is_install_run_command_agent: Optional[pulumi.Input[builtins.bool]] = None,
                 is_lts: Optional[pulumi.Input[builtins.bool]] = None,
                 is_support_cloud_init: Optional[pulumi.Input[builtins.bool]] = None,
                 kernel: Optional[pulumi.Input[builtins.str]] = None,
                 license_type: Optional[pulumi.Input[builtins.str]] = None,
                 os_name: Optional[pulumi.Input[builtins.str]] = None,
                 os_type: Optional[pulumi.Input[builtins.str]] = None,
                 platform: Optional[pulumi.Input[builtins.str]] = None,
                 platform_version: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 share_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 share_status: Optional[pulumi.Input[builtins.str]] = None,
                 size: Optional[pulumi.Input[builtins.int]] = None,
                 snapshot_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
                 snapshots: Optional[pulumi.Input[Sequence[pulumi.Input['ImageSnapshotArgs']]]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ImageTagArgs']]]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None,
                 virtual_size: Optional[pulumi.Input[builtins.float]] = None,
                 visibility: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Image resources.
        :param pulumi.Input[builtins.str] architecture: 镜像的架构类型。可以选择amd64（x86计算）、arm64（ARM计算）类型。
        :param pulumi.Input[builtins.str] boot_mode: 镜像的启动模式。可以选择BIOS、UEFI类型。
        :param pulumi.Input[builtins.str] created_at: 镜像创建时间
        :param pulumi.Input[builtins.str] description: 镜像描述。必须以字母、汉字开头。只能包含中文、字母、数字、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、英文句号“.”、中文逗号“，”、中文句号“。”和空格。长度限制为0～255个字符。不填默认为空。
        :param pulumi.Input['ImageDetectionResultsArgs'] detection_results: 镜像的检测结果。
        :param pulumi.Input[builtins.str] image_id: 镜像ID。
        :param pulumi.Input[builtins.str] image_name: 镜像名称。必须以字母、汉字开头。只能包含中文、字母、数字、下划线“_”、中划线“-”、英文句号“.”。长度限制为1 ~ 128个字符。
        :param pulumi.Input[builtins.str] image_owner_id: 镜像所属的账号ID。
        :param pulumi.Input[builtins.str] instance_id: 实例ID。本参数与SnapshotId、SnapshotGroupId参数，三选一必填。
        :param pulumi.Input[builtins.bool] is_install_run_command_agent: 镜像中是否安装了云助手Agent。
        :param pulumi.Input[builtins.bool] is_lts: 公共镜像是否长期维护。
        :param pulumi.Input[builtins.bool] is_support_cloud_init: 镜像是否支持Cloud-init。
        :param pulumi.Input[builtins.str] kernel: 镜像的内核版本。
        :param pulumi.Input[builtins.str] license_type: 镜像许可证类型。VolcanoEngine：默认，根据您设置的platform，采用官方渠道的许可证。BYOL：自带许可证（BYOL）。
        :param pulumi.Input[builtins.str] os_name: 镜像操作系统的名称。
        :param pulumi.Input[builtins.str] os_type: 操作系统类型。
        :param pulumi.Input[builtins.str] platform: 镜像操作系统的发行版本。可以选择CentOS、Debian、veLinux、Windows Server、Fedora、OpenSUSE、Ubuntu。
        :param pulumi.Input[builtins.str] platform_version: 镜像的发行版本。
        :param pulumi.Input[builtins.str] project_name: 资源所属项目。调用接口账号若仅拥有部分项目权限时必须传入有权限的项目信息。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] share_permissions: 镜像共享的账户
        :param pulumi.Input[builtins.str] share_status: 镜像共享状态。HasShared：自定义镜像已被共享给其他用户。当自定义镜像未被共享或使用公共镜像时，ShareStatus返回为空。
        :param pulumi.Input[builtins.int] size: 镜像大小，单位为GiB。
        :param pulumi.Input[builtins.str] snapshot_group_id: 快照一致性组ID，表示使用快照一致性组创建自定义镜像。本参数与SnapshotId、InstanceId参数，三选一必填。
        :param pulumi.Input[builtins.str] snapshot_id: 系统盘快照ID，表示使用系统盘快照创建自定义镜像。本参数与InstanceId、SnapshotGroupId参数，三选一必填。
        :param pulumi.Input[builtins.str] status: 镜像的状态。
        :param pulumi.Input[builtins.str] updated_at: 镜像更新时间
        :param pulumi.Input[builtins.float] virtual_size: 镜像大小，单位为Byte。
        :param pulumi.Input[builtins.str] visibility: 镜像的可见性。public：公共镜像。private：私有镜像。shared：共享镜像。
        """
        if architecture is not None:
            pulumi.set(__self__, "architecture", architecture)
        if boot_mode is not None:
            pulumi.set(__self__, "boot_mode", boot_mode)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if detection_results is not None:
            pulumi.set(__self__, "detection_results", detection_results)
        if image_id is not None:
            pulumi.set(__self__, "image_id", image_id)
        if image_name is not None:
            pulumi.set(__self__, "image_name", image_name)
        if image_owner_id is not None:
            pulumi.set(__self__, "image_owner_id", image_owner_id)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if is_install_run_command_agent is not None:
            pulumi.set(__self__, "is_install_run_command_agent", is_install_run_command_agent)
        if is_lts is not None:
            pulumi.set(__self__, "is_lts", is_lts)
        if is_support_cloud_init is not None:
            pulumi.set(__self__, "is_support_cloud_init", is_support_cloud_init)
        if kernel is not None:
            pulumi.set(__self__, "kernel", kernel)
        if license_type is not None:
            pulumi.set(__self__, "license_type", license_type)
        if os_name is not None:
            pulumi.set(__self__, "os_name", os_name)
        if os_type is not None:
            pulumi.set(__self__, "os_type", os_type)
        if platform is not None:
            pulumi.set(__self__, "platform", platform)
        if platform_version is not None:
            pulumi.set(__self__, "platform_version", platform_version)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if share_permissions is not None:
            pulumi.set(__self__, "share_permissions", share_permissions)
        if share_status is not None:
            pulumi.set(__self__, "share_status", share_status)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if snapshot_group_id is not None:
            pulumi.set(__self__, "snapshot_group_id", snapshot_group_id)
        if snapshot_id is not None:
            pulumi.set(__self__, "snapshot_id", snapshot_id)
        if snapshots is not None:
            pulumi.set(__self__, "snapshots", snapshots)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if virtual_size is not None:
            pulumi.set(__self__, "virtual_size", virtual_size)
        if visibility is not None:
            pulumi.set(__self__, "visibility", visibility)

    @property
    @pulumi.getter
    def architecture(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像的架构类型。可以选择amd64（x86计算）、arm64（ARM计算）类型。
        """
        return pulumi.get(self, "architecture")

    @architecture.setter
    def architecture(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "architecture", value)

    @property
    @pulumi.getter(name="bootMode")
    def boot_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像的启动模式。可以选择BIOS、UEFI类型。
        """
        return pulumi.get(self, "boot_mode")

    @boot_mode.setter
    def boot_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "boot_mode", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像创建时间
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像描述。必须以字母、汉字开头。只能包含中文、字母、数字、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、英文句号“.”、中文逗号“，”、中文句号“。”和空格。长度限制为0～255个字符。不填默认为空。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="detectionResults")
    def detection_results(self) -> Optional[pulumi.Input['ImageDetectionResultsArgs']]:
        """
        镜像的检测结果。
        """
        return pulumi.get(self, "detection_results")

    @detection_results.setter
    def detection_results(self, value: Optional[pulumi.Input['ImageDetectionResultsArgs']]):
        pulumi.set(self, "detection_results", value)

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像ID。
        """
        return pulumi.get(self, "image_id")

    @image_id.setter
    def image_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_id", value)

    @property
    @pulumi.getter(name="imageName")
    def image_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像名称。必须以字母、汉字开头。只能包含中文、字母、数字、下划线“_”、中划线“-”、英文句号“.”。长度限制为1 ~ 128个字符。
        """
        return pulumi.get(self, "image_name")

    @image_name.setter
    def image_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_name", value)

    @property
    @pulumi.getter(name="imageOwnerId")
    def image_owner_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像所属的账号ID。
        """
        return pulumi.get(self, "image_owner_id")

    @image_owner_id.setter
    def image_owner_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_owner_id", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例ID。本参数与SnapshotId、SnapshotGroupId参数，三选一必填。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="isInstallRunCommandAgent")
    def is_install_run_command_agent(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        镜像中是否安装了云助手Agent。
        """
        return pulumi.get(self, "is_install_run_command_agent")

    @is_install_run_command_agent.setter
    def is_install_run_command_agent(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_install_run_command_agent", value)

    @property
    @pulumi.getter(name="isLts")
    def is_lts(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        公共镜像是否长期维护。
        """
        return pulumi.get(self, "is_lts")

    @is_lts.setter
    def is_lts(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_lts", value)

    @property
    @pulumi.getter(name="isSupportCloudInit")
    def is_support_cloud_init(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        镜像是否支持Cloud-init。
        """
        return pulumi.get(self, "is_support_cloud_init")

    @is_support_cloud_init.setter
    def is_support_cloud_init(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_support_cloud_init", value)

    @property
    @pulumi.getter
    def kernel(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像的内核版本。
        """
        return pulumi.get(self, "kernel")

    @kernel.setter
    def kernel(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kernel", value)

    @property
    @pulumi.getter(name="licenseType")
    def license_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像许可证类型。VolcanoEngine：默认，根据您设置的platform，采用官方渠道的许可证。BYOL：自带许可证（BYOL）。
        """
        return pulumi.get(self, "license_type")

    @license_type.setter
    def license_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "license_type", value)

    @property
    @pulumi.getter(name="osName")
    def os_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像操作系统的名称。
        """
        return pulumi.get(self, "os_name")

    @os_name.setter
    def os_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "os_name", value)

    @property
    @pulumi.getter(name="osType")
    def os_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        操作系统类型。
        """
        return pulumi.get(self, "os_type")

    @os_type.setter
    def os_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "os_type", value)

    @property
    @pulumi.getter
    def platform(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像操作系统的发行版本。可以选择CentOS、Debian、veLinux、Windows Server、Fedora、OpenSUSE、Ubuntu。
        """
        return pulumi.get(self, "platform")

    @platform.setter
    def platform(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "platform", value)

    @property
    @pulumi.getter(name="platformVersion")
    def platform_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像的发行版本。
        """
        return pulumi.get(self, "platform_version")

    @platform_version.setter
    def platform_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "platform_version", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        资源所属项目。调用接口账号若仅拥有部分项目权限时必须传入有权限的项目信息。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="sharePermissions")
    def share_permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        镜像共享的账户
        """
        return pulumi.get(self, "share_permissions")

    @share_permissions.setter
    def share_permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "share_permissions", value)

    @property
    @pulumi.getter(name="shareStatus")
    def share_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像共享状态。HasShared：自定义镜像已被共享给其他用户。当自定义镜像未被共享或使用公共镜像时，ShareStatus返回为空。
        """
        return pulumi.get(self, "share_status")

    @share_status.setter
    def share_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "share_status", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        镜像大小，单位为GiB。
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter(name="snapshotGroupId")
    def snapshot_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        快照一致性组ID，表示使用快照一致性组创建自定义镜像。本参数与SnapshotId、InstanceId参数，三选一必填。
        """
        return pulumi.get(self, "snapshot_group_id")

    @snapshot_group_id.setter
    def snapshot_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "snapshot_group_id", value)

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        系统盘快照ID，表示使用系统盘快照创建自定义镜像。本参数与InstanceId、SnapshotGroupId参数，三选一必填。
        """
        return pulumi.get(self, "snapshot_id")

    @snapshot_id.setter
    def snapshot_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "snapshot_id", value)

    @property
    @pulumi.getter
    def snapshots(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ImageSnapshotArgs']]]]:
        return pulumi.get(self, "snapshots")

    @snapshots.setter
    def snapshots(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ImageSnapshotArgs']]]]):
        pulumi.set(self, "snapshots", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像的状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ImageTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ImageTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像更新时间
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter(name="virtualSize")
    def virtual_size(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        镜像大小，单位为Byte。
        """
        return pulumi.get(self, "virtual_size")

    @virtual_size.setter
    def virtual_size(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "virtual_size", value)

    @property
    @pulumi.getter
    def visibility(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像的可见性。public：公共镜像。private：私有镜像。shared：共享镜像。
        """
        return pulumi.get(self, "visibility")

    @visibility.setter
    def visibility(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "visibility", value)


@pulumi.type_token("bytepluscc:ecs/image:Image")
class Image(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 image_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 share_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 snapshot_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ImageTagArgs', 'ImageTagArgsDict']]]]] = None,
                 __props__=None):
        """
        镜像是包含了云服务器实例所需的基本操作系统、应用数据的特殊文件。创建实例时，必须选择镜像。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        image_demo = bytepluscc.ecs.Image("ImageDemo",
            description="ImageDemo Example",
            image_name="image-demo",
            instance_id="i-ydzhj1el8gr9cxxdnxxxx",
            project_name="default",
            share_permissions=["2000000***"],
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:ecs/image:Image example "image_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 镜像描述。必须以字母、汉字开头。只能包含中文、字母、数字、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、英文句号“.”、中文逗号“，”、中文句号“。”和空格。长度限制为0～255个字符。不填默认为空。
        :param pulumi.Input[builtins.str] image_name: 镜像名称。必须以字母、汉字开头。只能包含中文、字母、数字、下划线“_”、中划线“-”、英文句号“.”。长度限制为1 ~ 128个字符。
        :param pulumi.Input[builtins.str] instance_id: 实例ID。本参数与SnapshotId、SnapshotGroupId参数，三选一必填。
        :param pulumi.Input[builtins.str] project_name: 资源所属项目。调用接口账号若仅拥有部分项目权限时必须传入有权限的项目信息。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] share_permissions: 镜像共享的账户
        :param pulumi.Input[builtins.str] snapshot_group_id: 快照一致性组ID，表示使用快照一致性组创建自定义镜像。本参数与SnapshotId、InstanceId参数，三选一必填。
        :param pulumi.Input[builtins.str] snapshot_id: 系统盘快照ID，表示使用系统盘快照创建自定义镜像。本参数与InstanceId、SnapshotGroupId参数，三选一必填。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ImageArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        镜像是包含了云服务器实例所需的基本操作系统、应用数据的特殊文件。创建实例时，必须选择镜像。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        image_demo = bytepluscc.ecs.Image("ImageDemo",
            description="ImageDemo Example",
            image_name="image-demo",
            instance_id="i-ydzhj1el8gr9cxxdnxxxx",
            project_name="default",
            share_permissions=["2000000***"],
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:ecs/image:Image example "image_id"
        ```

        :param str resource_name: The name of the resource.
        :param ImageArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ImageArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 image_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 share_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 snapshot_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ImageTagArgs', 'ImageTagArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ImageArgs.__new__(ImageArgs)

            __props__.__dict__["description"] = description
            if image_name is None and not opts.urn:
                raise TypeError("Missing required property 'image_name'")
            __props__.__dict__["image_name"] = image_name
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["share_permissions"] = share_permissions
            __props__.__dict__["snapshot_group_id"] = snapshot_group_id
            __props__.__dict__["snapshot_id"] = snapshot_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["architecture"] = None
            __props__.__dict__["boot_mode"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["detection_results"] = None
            __props__.__dict__["image_id"] = None
            __props__.__dict__["image_owner_id"] = None
            __props__.__dict__["is_install_run_command_agent"] = None
            __props__.__dict__["is_lts"] = None
            __props__.__dict__["is_support_cloud_init"] = None
            __props__.__dict__["kernel"] = None
            __props__.__dict__["license_type"] = None
            __props__.__dict__["os_name"] = None
            __props__.__dict__["os_type"] = None
            __props__.__dict__["platform"] = None
            __props__.__dict__["platform_version"] = None
            __props__.__dict__["share_status"] = None
            __props__.__dict__["size"] = None
            __props__.__dict__["snapshots"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_at"] = None
            __props__.__dict__["virtual_size"] = None
            __props__.__dict__["visibility"] = None
        super(Image, __self__).__init__(
            'bytepluscc:ecs/image:Image',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            architecture: Optional[pulumi.Input[builtins.str]] = None,
            boot_mode: Optional[pulumi.Input[builtins.str]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            detection_results: Optional[pulumi.Input[Union['ImageDetectionResultsArgs', 'ImageDetectionResultsArgsDict']]] = None,
            image_id: Optional[pulumi.Input[builtins.str]] = None,
            image_name: Optional[pulumi.Input[builtins.str]] = None,
            image_owner_id: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            is_install_run_command_agent: Optional[pulumi.Input[builtins.bool]] = None,
            is_lts: Optional[pulumi.Input[builtins.bool]] = None,
            is_support_cloud_init: Optional[pulumi.Input[builtins.bool]] = None,
            kernel: Optional[pulumi.Input[builtins.str]] = None,
            license_type: Optional[pulumi.Input[builtins.str]] = None,
            os_name: Optional[pulumi.Input[builtins.str]] = None,
            os_type: Optional[pulumi.Input[builtins.str]] = None,
            platform: Optional[pulumi.Input[builtins.str]] = None,
            platform_version: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            share_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            share_status: Optional[pulumi.Input[builtins.str]] = None,
            size: Optional[pulumi.Input[builtins.int]] = None,
            snapshot_group_id: Optional[pulumi.Input[builtins.str]] = None,
            snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
            snapshots: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ImageSnapshotArgs', 'ImageSnapshotArgsDict']]]]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ImageTagArgs', 'ImageTagArgsDict']]]]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None,
            virtual_size: Optional[pulumi.Input[builtins.float]] = None,
            visibility: Optional[pulumi.Input[builtins.str]] = None) -> 'Image':
        """
        Get an existing Image resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] architecture: 镜像的架构类型。可以选择amd64（x86计算）、arm64（ARM计算）类型。
        :param pulumi.Input[builtins.str] boot_mode: 镜像的启动模式。可以选择BIOS、UEFI类型。
        :param pulumi.Input[builtins.str] created_at: 镜像创建时间
        :param pulumi.Input[builtins.str] description: 镜像描述。必须以字母、汉字开头。只能包含中文、字母、数字、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、英文句号“.”、中文逗号“，”、中文句号“。”和空格。长度限制为0～255个字符。不填默认为空。
        :param pulumi.Input[Union['ImageDetectionResultsArgs', 'ImageDetectionResultsArgsDict']] detection_results: 镜像的检测结果。
        :param pulumi.Input[builtins.str] image_id: 镜像ID。
        :param pulumi.Input[builtins.str] image_name: 镜像名称。必须以字母、汉字开头。只能包含中文、字母、数字、下划线“_”、中划线“-”、英文句号“.”。长度限制为1 ~ 128个字符。
        :param pulumi.Input[builtins.str] image_owner_id: 镜像所属的账号ID。
        :param pulumi.Input[builtins.str] instance_id: 实例ID。本参数与SnapshotId、SnapshotGroupId参数，三选一必填。
        :param pulumi.Input[builtins.bool] is_install_run_command_agent: 镜像中是否安装了云助手Agent。
        :param pulumi.Input[builtins.bool] is_lts: 公共镜像是否长期维护。
        :param pulumi.Input[builtins.bool] is_support_cloud_init: 镜像是否支持Cloud-init。
        :param pulumi.Input[builtins.str] kernel: 镜像的内核版本。
        :param pulumi.Input[builtins.str] license_type: 镜像许可证类型。VolcanoEngine：默认，根据您设置的platform，采用官方渠道的许可证。BYOL：自带许可证（BYOL）。
        :param pulumi.Input[builtins.str] os_name: 镜像操作系统的名称。
        :param pulumi.Input[builtins.str] os_type: 操作系统类型。
        :param pulumi.Input[builtins.str] platform: 镜像操作系统的发行版本。可以选择CentOS、Debian、veLinux、Windows Server、Fedora、OpenSUSE、Ubuntu。
        :param pulumi.Input[builtins.str] platform_version: 镜像的发行版本。
        :param pulumi.Input[builtins.str] project_name: 资源所属项目。调用接口账号若仅拥有部分项目权限时必须传入有权限的项目信息。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] share_permissions: 镜像共享的账户
        :param pulumi.Input[builtins.str] share_status: 镜像共享状态。HasShared：自定义镜像已被共享给其他用户。当自定义镜像未被共享或使用公共镜像时，ShareStatus返回为空。
        :param pulumi.Input[builtins.int] size: 镜像大小，单位为GiB。
        :param pulumi.Input[builtins.str] snapshot_group_id: 快照一致性组ID，表示使用快照一致性组创建自定义镜像。本参数与SnapshotId、InstanceId参数，三选一必填。
        :param pulumi.Input[builtins.str] snapshot_id: 系统盘快照ID，表示使用系统盘快照创建自定义镜像。本参数与InstanceId、SnapshotGroupId参数，三选一必填。
        :param pulumi.Input[builtins.str] status: 镜像的状态。
        :param pulumi.Input[builtins.str] updated_at: 镜像更新时间
        :param pulumi.Input[builtins.float] virtual_size: 镜像大小，单位为Byte。
        :param pulumi.Input[builtins.str] visibility: 镜像的可见性。public：公共镜像。private：私有镜像。shared：共享镜像。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ImageState.__new__(_ImageState)

        __props__.__dict__["architecture"] = architecture
        __props__.__dict__["boot_mode"] = boot_mode
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["detection_results"] = detection_results
        __props__.__dict__["image_id"] = image_id
        __props__.__dict__["image_name"] = image_name
        __props__.__dict__["image_owner_id"] = image_owner_id
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["is_install_run_command_agent"] = is_install_run_command_agent
        __props__.__dict__["is_lts"] = is_lts
        __props__.__dict__["is_support_cloud_init"] = is_support_cloud_init
        __props__.__dict__["kernel"] = kernel
        __props__.__dict__["license_type"] = license_type
        __props__.__dict__["os_name"] = os_name
        __props__.__dict__["os_type"] = os_type
        __props__.__dict__["platform"] = platform
        __props__.__dict__["platform_version"] = platform_version
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["share_permissions"] = share_permissions
        __props__.__dict__["share_status"] = share_status
        __props__.__dict__["size"] = size
        __props__.__dict__["snapshot_group_id"] = snapshot_group_id
        __props__.__dict__["snapshot_id"] = snapshot_id
        __props__.__dict__["snapshots"] = snapshots
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["virtual_size"] = virtual_size
        __props__.__dict__["visibility"] = visibility
        return Image(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def architecture(self) -> pulumi.Output[builtins.str]:
        """
        镜像的架构类型。可以选择amd64（x86计算）、arm64（ARM计算）类型。
        """
        return pulumi.get(self, "architecture")

    @property
    @pulumi.getter(name="bootMode")
    def boot_mode(self) -> pulumi.Output[builtins.str]:
        """
        镜像的启动模式。可以选择BIOS、UEFI类型。
        """
        return pulumi.get(self, "boot_mode")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        镜像创建时间
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        镜像描述。必须以字母、汉字开头。只能包含中文、字母、数字、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、英文句号“.”、中文逗号“，”、中文句号“。”和空格。长度限制为0～255个字符。不填默认为空。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="detectionResults")
    def detection_results(self) -> pulumi.Output['outputs.ImageDetectionResults']:
        """
        镜像的检测结果。
        """
        return pulumi.get(self, "detection_results")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> pulumi.Output[builtins.str]:
        """
        镜像ID。
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="imageName")
    def image_name(self) -> pulumi.Output[builtins.str]:
        """
        镜像名称。必须以字母、汉字开头。只能包含中文、字母、数字、下划线“_”、中划线“-”、英文句号“.”。长度限制为1 ~ 128个字符。
        """
        return pulumi.get(self, "image_name")

    @property
    @pulumi.getter(name="imageOwnerId")
    def image_owner_id(self) -> pulumi.Output[builtins.str]:
        """
        镜像所属的账号ID。
        """
        return pulumi.get(self, "image_owner_id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        实例ID。本参数与SnapshotId、SnapshotGroupId参数，三选一必填。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="isInstallRunCommandAgent")
    def is_install_run_command_agent(self) -> pulumi.Output[builtins.bool]:
        """
        镜像中是否安装了云助手Agent。
        """
        return pulumi.get(self, "is_install_run_command_agent")

    @property
    @pulumi.getter(name="isLts")
    def is_lts(self) -> pulumi.Output[builtins.bool]:
        """
        公共镜像是否长期维护。
        """
        return pulumi.get(self, "is_lts")

    @property
    @pulumi.getter(name="isSupportCloudInit")
    def is_support_cloud_init(self) -> pulumi.Output[builtins.bool]:
        """
        镜像是否支持Cloud-init。
        """
        return pulumi.get(self, "is_support_cloud_init")

    @property
    @pulumi.getter
    def kernel(self) -> pulumi.Output[builtins.str]:
        """
        镜像的内核版本。
        """
        return pulumi.get(self, "kernel")

    @property
    @pulumi.getter(name="licenseType")
    def license_type(self) -> pulumi.Output[builtins.str]:
        """
        镜像许可证类型。VolcanoEngine：默认，根据您设置的platform，采用官方渠道的许可证。BYOL：自带许可证（BYOL）。
        """
        return pulumi.get(self, "license_type")

    @property
    @pulumi.getter(name="osName")
    def os_name(self) -> pulumi.Output[builtins.str]:
        """
        镜像操作系统的名称。
        """
        return pulumi.get(self, "os_name")

    @property
    @pulumi.getter(name="osType")
    def os_type(self) -> pulumi.Output[builtins.str]:
        """
        操作系统类型。
        """
        return pulumi.get(self, "os_type")

    @property
    @pulumi.getter
    def platform(self) -> pulumi.Output[builtins.str]:
        """
        镜像操作系统的发行版本。可以选择CentOS、Debian、veLinux、Windows Server、Fedora、OpenSUSE、Ubuntu。
        """
        return pulumi.get(self, "platform")

    @property
    @pulumi.getter(name="platformVersion")
    def platform_version(self) -> pulumi.Output[builtins.str]:
        """
        镜像的发行版本。
        """
        return pulumi.get(self, "platform_version")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        资源所属项目。调用接口账号若仅拥有部分项目权限时必须传入有权限的项目信息。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="sharePermissions")
    def share_permissions(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        镜像共享的账户
        """
        return pulumi.get(self, "share_permissions")

    @property
    @pulumi.getter(name="shareStatus")
    def share_status(self) -> pulumi.Output[builtins.str]:
        """
        镜像共享状态。HasShared：自定义镜像已被共享给其他用户。当自定义镜像未被共享或使用公共镜像时，ShareStatus返回为空。
        """
        return pulumi.get(self, "share_status")

    @property
    @pulumi.getter
    def size(self) -> pulumi.Output[builtins.int]:
        """
        镜像大小，单位为GiB。
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter(name="snapshotGroupId")
    def snapshot_group_id(self) -> pulumi.Output[builtins.str]:
        """
        快照一致性组ID，表示使用快照一致性组创建自定义镜像。本参数与SnapshotId、InstanceId参数，三选一必填。
        """
        return pulumi.get(self, "snapshot_group_id")

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> pulumi.Output[builtins.str]:
        """
        系统盘快照ID，表示使用系统盘快照创建自定义镜像。本参数与InstanceId、SnapshotGroupId参数，三选一必填。
        """
        return pulumi.get(self, "snapshot_id")

    @property
    @pulumi.getter
    def snapshots(self) -> pulumi.Output[Sequence['outputs.ImageSnapshot']]:
        return pulumi.get(self, "snapshots")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        镜像的状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.ImageTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        镜像更新时间
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="virtualSize")
    def virtual_size(self) -> pulumi.Output[builtins.float]:
        """
        镜像大小，单位为Byte。
        """
        return pulumi.get(self, "virtual_size")

    @property
    @pulumi.getter
    def visibility(self) -> pulumi.Output[builtins.str]:
        """
        镜像的可见性。public：公共镜像。private：私有镜像。shared：共享镜像。
        """
        return pulumi.get(self, "visibility")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetPolicyResult',
    'AwaitableGetPolicyResult',
    'get_policy',
    'get_policy_output',
]

@pulumi.output_type
class GetPolicyResult:
    """
    A collection of values returned by getPolicy.
    """
    def __init__(__self__, attachment_count=None, category=None, created_time=None, description=None, id=None, is_service_role_policy=None, policy_document=None, policy_name=None, policy_roles=None, policy_trn=None, policy_type=None, policy_user_groups=None, policy_users=None, updated_time=None):
        if attachment_count and not isinstance(attachment_count, int):
            raise TypeError("Expected argument 'attachment_count' to be a int")
        pulumi.set(__self__, "attachment_count", attachment_count)
        if category and not isinstance(category, str):
            raise TypeError("Expected argument 'category' to be a str")
        pulumi.set(__self__, "category", category)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_service_role_policy and not isinstance(is_service_role_policy, int):
            raise TypeError("Expected argument 'is_service_role_policy' to be a int")
        pulumi.set(__self__, "is_service_role_policy", is_service_role_policy)
        if policy_document and not isinstance(policy_document, str):
            raise TypeError("Expected argument 'policy_document' to be a str")
        pulumi.set(__self__, "policy_document", policy_document)
        if policy_name and not isinstance(policy_name, str):
            raise TypeError("Expected argument 'policy_name' to be a str")
        pulumi.set(__self__, "policy_name", policy_name)
        if policy_roles and not isinstance(policy_roles, list):
            raise TypeError("Expected argument 'policy_roles' to be a list")
        pulumi.set(__self__, "policy_roles", policy_roles)
        if policy_trn and not isinstance(policy_trn, str):
            raise TypeError("Expected argument 'policy_trn' to be a str")
        pulumi.set(__self__, "policy_trn", policy_trn)
        if policy_type and not isinstance(policy_type, str):
            raise TypeError("Expected argument 'policy_type' to be a str")
        pulumi.set(__self__, "policy_type", policy_type)
        if policy_user_groups and not isinstance(policy_user_groups, list):
            raise TypeError("Expected argument 'policy_user_groups' to be a list")
        pulumi.set(__self__, "policy_user_groups", policy_user_groups)
        if policy_users and not isinstance(policy_users, list):
            raise TypeError("Expected argument 'policy_users' to be a list")
        pulumi.set(__self__, "policy_users", policy_users)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="attachmentCount")
    def attachment_count(self) -> builtins.int:
        """
        策略绑定的身份数量。
        """
        return pulumi.get(self, "attachment_count")

    @property
    @pulumi.getter
    def category(self) -> builtins.str:
        """
        系统预设策略所属的分类，通常为服务代码，对于自定义策略该字段不会返回值。
        """
        return pulumi.get(self, "category")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        策略创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        策略描述，长度不超过128。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isServiceRolePolicy")
    def is_service_role_policy(self) -> builtins.int:
        """
        是否是服务关联角色的策略，0代表否，1代表是。
        """
        return pulumi.get(self, "is_service_role_policy")

    @property
    @pulumi.getter(name="policyDocument")
    def policy_document(self) -> builtins.str:
        """
        策略语法内容，例如：{"Statement":[{"Effect":"Allow","Action":["iam:","tag:"],"Resource":["*"]}]}
        """
        return pulumi.get(self, "policy_document")

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> builtins.str:
        """
        策略名，长度1~64，支持英文、数字和+=,.@-_符号。
        """
        return pulumi.get(self, "policy_name")

    @property
    @pulumi.getter(name="policyRoles")
    def policy_roles(self) -> Sequence['outputs.GetPolicyPolicyRoleResult']:
        """
        策略绑定的角色列表。
        """
        return pulumi.get(self, "policy_roles")

    @property
    @pulumi.getter(name="policyTrn")
    def policy_trn(self) -> builtins.str:
        """
        策略的TRN。
        """
        return pulumi.get(self, "policy_trn")

    @property
    @pulumi.getter(name="policyType")
    def policy_type(self) -> builtins.str:
        """
        策略类型。System代表系统预设策略，Custom代表自定义策略。
        """
        return pulumi.get(self, "policy_type")

    @property
    @pulumi.getter(name="policyUserGroups")
    def policy_user_groups(self) -> Sequence['outputs.GetPolicyPolicyUserGroupResult']:
        """
        策略绑定的用户组列表。
        """
        return pulumi.get(self, "policy_user_groups")

    @property
    @pulumi.getter(name="policyUsers")
    def policy_users(self) -> Sequence['outputs.GetPolicyPolicyUserResult']:
        """
        策略绑定的用户列表。
        """
        return pulumi.get(self, "policy_users")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        策略更新时间。
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetPolicyResult(GetPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPolicyResult(
            attachment_count=self.attachment_count,
            category=self.category,
            created_time=self.created_time,
            description=self.description,
            id=self.id,
            is_service_role_policy=self.is_service_role_policy,
            policy_document=self.policy_document,
            policy_name=self.policy_name,
            policy_roles=self.policy_roles,
            policy_trn=self.policy_trn,
            policy_type=self.policy_type,
            policy_user_groups=self.policy_user_groups,
            policy_users=self.policy_users,
            updated_time=self.updated_time)


def get_policy(id: Optional[builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPolicyResult:
    """
    Data Source schema for Byteplus::IAM::Policy


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:iam/getPolicy:getPolicy', __args__, opts=opts, typ=GetPolicyResult).value

    return AwaitableGetPolicyResult(
        attachment_count=pulumi.get(__ret__, 'attachment_count'),
        category=pulumi.get(__ret__, 'category'),
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        is_service_role_policy=pulumi.get(__ret__, 'is_service_role_policy'),
        policy_document=pulumi.get(__ret__, 'policy_document'),
        policy_name=pulumi.get(__ret__, 'policy_name'),
        policy_roles=pulumi.get(__ret__, 'policy_roles'),
        policy_trn=pulumi.get(__ret__, 'policy_trn'),
        policy_type=pulumi.get(__ret__, 'policy_type'),
        policy_user_groups=pulumi.get(__ret__, 'policy_user_groups'),
        policy_users=pulumi.get(__ret__, 'policy_users'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_policy_output(id: Optional[pulumi.Input[builtins.str]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPolicyResult]:
    """
    Data Source schema for Byteplus::IAM::Policy


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:iam/getPolicy:getPolicy', __args__, opts=opts, typ=GetPolicyResult)
    return __ret__.apply(lambda __response__: GetPolicyResult(
        attachment_count=pulumi.get(__response__, 'attachment_count'),
        category=pulumi.get(__response__, 'category'),
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        is_service_role_policy=pulumi.get(__response__, 'is_service_role_policy'),
        policy_document=pulumi.get(__response__, 'policy_document'),
        policy_name=pulumi.get(__response__, 'policy_name'),
        policy_roles=pulumi.get(__response__, 'policy_roles'),
        policy_trn=pulumi.get(__response__, 'policy_trn'),
        policy_type=pulumi.get(__response__, 'policy_type'),
        policy_user_groups=pulumi.get(__response__, 'policy_user_groups'),
        policy_users=pulumi.get(__response__, 'policy_users'),
        updated_time=pulumi.get(__response__, 'updated_time')))
